@@ -80,7 +80,7 @@
 /* Copy the first part of user declarations.  */
 #line 1 "parsedate.y"
 
-/* $Revision: 1.1 $
+/* $Revision: 1.2 $
 **
 **  Originally written by Steven M. Bellovin <smb@research.att.com> while
 **  at the University of North Carolina at Chapel Hill.  Later tweaked by
@@ -102,6 +102,7 @@
 #include <sys/types.h>
 #include <ctype.h>
 #include <time.h>
+#include <string.h>
 
 int date_lex();
 
@@ -192,13 +193,13 @@ static void		date_error();
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 100 "parsedate.y"
+#line 101 "parsedate.y"
 typedef union YYSTYPE {
     time_t		Number;
     enum _MERIDIAN	Meridian;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 201 "parsedate.c"
+#line 202 "parsedate.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -210,7 +211,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 213 "parsedate.c"
+#line 214 "parsedate.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -388,10 +389,10 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned short yyrline[] =
 {
-       0,   114,   114,   115,   118,   127,   131,   134,   139,   151,
-     157,   164,   170,   180,   184,   188,   196,   202,   223,   227,
-     239,   243,   248,   252,   257,   264,   267,   270,   273,   278,
-     281
+       0,   115,   115,   116,   119,   128,   132,   135,   140,   152,
+     158,   165,   171,   181,   185,   189,   197,   203,   224,   228,
+     240,   244,   249,   253,   258,   265,   268,   271,   274,   279,
+     282
 };
 #endif
 
@@ -530,6 +531,7 @@ static const unsigned char yystos[] =
 #define YYABORT		goto yyabortlab
 #define YYERROR		goto yyerrlab1
 
+
 /* Like YYERROR except do call yyerror.  This remains here temporarily
    to ease the transition to the new meaning of YYERROR, for GCC.
    Once GCC version 2 has supplanted version 1, this can go.  */
@@ -1112,7 +1114,7 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 118 "parsedate.y"
+#line 119 "parsedate.y"
     {
 	    yyHaveTime++;
 #ifdef lint
@@ -1125,7 +1127,7 @@ yyreduce:
     break;
 
   case 5:
-#line 127 "parsedate.y"
+#line 128 "parsedate.y"
     {
 	    yyHaveTime++;
 	    yyTimezone = yyvsp[0].Number;
@@ -1133,21 +1135,21 @@ yyreduce:
     break;
 
   case 6:
-#line 131 "parsedate.y"
+#line 132 "parsedate.y"
     {
 	    yyHaveDate++;
 	}
     break;
 
   case 7:
-#line 134 "parsedate.y"
+#line 135 "parsedate.y"
     {
 	    yyHaveRel = 1;
 	}
     break;
 
   case 8:
-#line 139 "parsedate.y"
+#line 140 "parsedate.y"
     {
 	    if (yyvsp[-1].Number < 100) {
 		yyHour = yyvsp[-1].Number;
@@ -1163,7 +1165,7 @@ yyreduce:
     break;
 
   case 9:
-#line 151 "parsedate.y"
+#line 152 "parsedate.y"
     {
 	    yyHour = yyvsp[-3].Number;
 	    yyMinutes = yyvsp[-1].Number;
@@ -1173,7 +1175,7 @@ yyreduce:
     break;
 
   case 10:
-#line 157 "parsedate.y"
+#line 158 "parsedate.y"
     {
 	    yyHour = yyvsp[-3].Number;
 	    yyMinutes = yyvsp[-1].Number;
@@ -1184,7 +1186,7 @@ yyreduce:
     break;
 
   case 11:
-#line 164 "parsedate.y"
+#line 165 "parsedate.y"
     {
 	    yyHour = yyvsp[-5].Number;
 	    yyMinutes = yyvsp[-3].Number;
@@ -1194,7 +1196,7 @@ yyreduce:
     break;
 
   case 12:
-#line 170 "parsedate.y"
+#line 171 "parsedate.y"
     {
 	    yyHour = yyvsp[-5].Number;
 	    yyMinutes = yyvsp[-3].Number;
@@ -1206,7 +1208,7 @@ yyreduce:
     break;
 
   case 13:
-#line 180 "parsedate.y"
+#line 181 "parsedate.y"
     {
 	    yyval.Number = yyvsp[0].Number;
 	    yyDSTmode = DSToff;
@@ -1214,7 +1216,7 @@ yyreduce:
     break;
 
   case 14:
-#line 184 "parsedate.y"
+#line 185 "parsedate.y"
     {
 	    yyval.Number = yyvsp[0].Number;
 	    yyDSTmode = DSTon;
@@ -1222,7 +1224,7 @@ yyreduce:
     break;
 
   case 15:
-#line 188 "parsedate.y"
+#line 189 "parsedate.y"
     {
 	    /* Only allow "GMT+300" and "GMT-0800" */
 	    if (yyvsp[-1].Number != 0) {
@@ -1234,7 +1236,7 @@ yyreduce:
     break;
 
   case 16:
-#line 196 "parsedate.y"
+#line 197 "parsedate.y"
     {
 	    yyval.Number = yyvsp[0].Number;
 	    yyDSTmode = DSToff;
@@ -1242,7 +1244,7 @@ yyreduce:
     break;
 
   case 17:
-#line 202 "parsedate.y"
+#line 203 "parsedate.y"
     {
 	    int		i;
 
@@ -1265,7 +1267,7 @@ yyreduce:
     break;
 
   case 18:
-#line 223 "parsedate.y"
+#line 224 "parsedate.y"
     {
 	    yyMonth = yyvsp[-2].Number;
 	    yyDay = yyvsp[0].Number;
@@ -1273,7 +1275,7 @@ yyreduce:
     break;
 
   case 19:
-#line 227 "parsedate.y"
+#line 228 "parsedate.y"
     {
 	    if (yyvsp[-4].Number > 100) {
 		yyYear = yyvsp[-4].Number;
@@ -1289,7 +1291,7 @@ yyreduce:
     break;
 
   case 20:
-#line 239 "parsedate.y"
+#line 240 "parsedate.y"
     {
 	    yyMonth = yyvsp[-1].Number;
 	    yyDay = yyvsp[0].Number;
@@ -1297,7 +1299,7 @@ yyreduce:
     break;
 
   case 21:
-#line 243 "parsedate.y"
+#line 244 "parsedate.y"
     {
 	    yyMonth = yyvsp[-3].Number;
 	    yyDay = yyvsp[-2].Number;
@@ -1306,7 +1308,7 @@ yyreduce:
     break;
 
   case 22:
-#line 248 "parsedate.y"
+#line 249 "parsedate.y"
     {
 	    yyDay = yyvsp[-1].Number;
 	    yyMonth = yyvsp[0].Number;
@@ -1314,7 +1316,7 @@ yyreduce:
     break;
 
   case 23:
-#line 252 "parsedate.y"
+#line 253 "parsedate.y"
     {
 	    yyDay = yyvsp[-2].Number;
 	    yyMonth = yyvsp[-1].Number;
@@ -1323,7 +1325,7 @@ yyreduce:
     break;
 
   case 24:
-#line 257 "parsedate.y"
+#line 258 "parsedate.y"
     {
 	    yyDay = yyvsp[-2].Number;
 	    yyMonth = yyvsp[-1].Number;
@@ -1332,42 +1334,42 @@ yyreduce:
     break;
 
   case 25:
-#line 264 "parsedate.y"
+#line 265 "parsedate.y"
     {
 	    yyRelSeconds += yyvsp[-1].Number * yyvsp[0].Number;
 	}
     break;
 
   case 26:
-#line 267 "parsedate.y"
+#line 268 "parsedate.y"
     {
 	    yyRelSeconds += yyvsp[-1].Number * yyvsp[0].Number;
 	}
     break;
 
   case 27:
-#line 270 "parsedate.y"
+#line 271 "parsedate.y"
     {
 	    yyRelMonth += yyvsp[-1].Number * yyvsp[0].Number;
 	}
     break;
 
   case 28:
-#line 273 "parsedate.y"
+#line 274 "parsedate.y"
     {
 	    yyRelMonth += yyvsp[-1].Number * yyvsp[0].Number;
 	}
     break;
 
   case 29:
-#line 278 "parsedate.y"
+#line 279 "parsedate.y"
     {
 	    yyval.Meridian = MER24;
 	}
     break;
 
   case 30:
-#line 281 "parsedate.y"
+#line 282 "parsedate.y"
     {
 	    yyval.Meridian = yyvsp[0].Meridian;
 	}
@@ -1376,8 +1378,8 @@ yyreduce:
 
     }
 
-/* Line 991 of yacc.c.  */
-#line 1380 "parsedate.c"
+/* Line 999 of yacc.c.  */
+#line 1382 "parsedate.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1491,29 +1493,13 @@ yyerrlab:
 
   /* Else will try to reuse lookahead token after shifting the error
      token.  */
-  goto yyerrlab2;
+  goto yyerrlab1;
 
 
 /*----------------------------------------------------.
 | yyerrlab1 -- error raised explicitly by an action.  |
 `----------------------------------------------------*/
 yyerrlab1:
-
-  /* Suppress GCC warning that yyerrlab1 is unused when no action
-     invokes YYERROR.  */
-#if defined (__GNUC_MINOR__) && 2093 <= (__GNUC__ * 1000 + __GNUC_MINOR__) \
-    && !defined __cplusplus
-  __attribute__ ((__unused__))
-#endif
-
-
-  goto yyerrlab2;
-
-
-/*---------------------------------------------------------------.
-| yyerrlab2 -- pop states until the error token can be shifted.  |
-`---------------------------------------------------------------*/
-yyerrlab2:
   yyerrstatus = 3;	/* Each real token shifted decrements this.  */
 
   for (;;)
@@ -1587,7 +1573,7 @@ yyreturn:
 }
 
 
-#line 286 "parsedate.y"
+#line 287 "parsedate.y"
 
 
 /* Month and day table. */
